@@ -1,5 +1,5 @@
 Impute <-
-function(x, FUN = median){
+function(x, FUN = function(x) median(x, na.rm=TRUE)) {
   
   if(is.function(FUN)) { 
     #  if FUN is a function, then save it under new name and 
